pub fn new_mem_object_id(
    call_tid: &Tid,
    return_arg: &Arg
) -> DataDomain<BitvectorDomain>
A return value that contains a pointer to the start of a new memory object. The ID of the memory object is given by the return register and the TID of the call instruction.