pub fn param_plus_unknown_offset(
    state: &mut State,
    extern_symbol: &ExternSymbol,
    param_index: usize
) -> DataDomain<BitvectorDomain>
A return value that adds an unknown offset to a given parameter. E.g. if the parameter is a pointer to a string, this return value would describe a pointer to an offset inside the string.