Function cwe_checker_lib::analysis::function_signature::stubs::return_value_stubs::param_plus_unknown_offset
source · pub fn param_plus_unknown_offset(
state: &mut State,
extern_symbol: &ExternSymbol,
param_index: usize
) -> DataDomain<BitvectorDomain>Expand description
A return value that adds an unknown offset to a given parameter. E.g. if the parameter is a pointer to a string, this return value would describe a pointer to an offset inside the string.